@@ -5,8 +5,14 @@
 #' @param dtm A `DocumentTermMatrix` object.
 #' @param n The maximum number of terms to represent.
 #' @param min_occ The minimum number of occurrences for a term to be retained.
+#' @param interactive If `TRUE`, show an interactive plot using [`tkplot`]. This
+#'   is the case by default for interactive sessions.
+#' @param vertex.label.cex The font size for vertex labels.
+#'   It is interpreted as a multiplication factor of some device-dependent base font size.
+#' @param ... Optional arguments passed to [`plot.igraph`] or [`tkplot`].
 #'
-#' @return The ID of the plot returned by [`tkplot`].
+#' @return The ID of the plot returned by [`tkplot`] if `interactive=TRUE`,
+#'   or `NULL` invisibly otherwise.
 #'
 #' @examples
 #'
@@ -17,7 +23,8 @@
 #'
 #' @export
 #'
-terms_graph <- function(dtm, n=100, min_occ=0) {
+terms_graph <- function(dtm, n=100, min_occ=0, interactive=base::interactive(),
+                        vertex.label.cex=1, ...) {
   if(min_occ > 0)
     dtm <- dtm[, col_sums(dtm) > min_occ]
 
@@ -30,9 +37,10 @@ terms_graph <- function(dtm, n=100, min_occ=0) {
   igraph::E(g1)$weight <- 1/igraph::edge_attr(g1, 'weight')
   g3 <- igraph::minimum.spanning.tree(g1)
   igraph::E(g3)$weight <- 1/igraph::E(g3)$weight
-  igraph::tkplot(g3, vertex.label=colnames(m),
-                 edge.width=(igraph::E(g3)$weight/max(igraph::E(g3)$weight))*10,
-                 vertex.size=0,
-                 vertex.label.cex=sqrt(10*eff/max(eff)),
-                 edge.curved=0.6)
+  do_plot <- if(interactive) igraph::tkplot else plot
+  do_plot(g3, ..., vertex.label=colnames(m),
+          edge.width=(igraph::E(g3)$weight/max(igraph::E(g3)$weight))*10,
+          vertex.size=0,
+          vertex.label.cex=sqrt(10*eff/max(eff))*vertex.label.cex,
+          edge.curved=0.6)
 }
